==> lxqt-panel-1.0.0.tar.xz: lxqt-panel-1.0.0/plugin-cpuload/translations/cpuload_ru.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ru">
<context>
    <name>LXQtCpuLoad</name>
    <message>
        <location filename="../lxqtcpuload.cpp" line="127"/>
        <source>CPU load %1%</source>
        <translation>Загрузка процессора %1%</translation>
    </message>
</context>
<context>
    <name>LXQtCpuLoadConfiguration</name>
    <message>
        <location filename="../lxqtcpuloadconfiguration.ui" line="14"/>
        <source>CPU Load Settings</source>
        <translation>Настройки загрузки процессора</translation>
    </message>
    <message>
        <location filename="../lxqtcpuloadconfiguration.ui" line="20"/>
        <source>General</source>
        <translation>Общие</translation>
    </message>
    <message>
        <location filename="../lxqtcpuloadconfiguration.ui" line="35"/>
        <source>Show text</source>
        <translation>Показать текст</translation>
    </message>
    <message>
        <location filename="../lxqtcpuloadconfiguration.ui" line="42"/>
        <source>Update interval:</source>
        <translation>Интервал обновления:</translation>
    </message>
    <message>
        <location filename="../lxqtcpuloadconfiguration.ui" line="49"/>
        <source>sec</source>
        <translation>сек</translation>
    </message>
    <message>
        <location filename="../lxqtcpuloadconfiguration.ui" line="71"/>
        <source>Bar orientation:</source>
        <translation>Ориентация шкалы:</translation>
    </message>
    <message>
        <location filename="../lxqtcpuloadconfiguration.ui" line="81"/>
        <source>Bar width:</source>
        <translation>Ширина шкалы:</translation>
    </message>
    <message>
        <location filename="../lxqtcpuloadconfiguration.cpp" line="68"/>
        <source>Bottom up</source>
        <translation>Снизу вверх</translation>
    </message>
    <message>
        <location filename="../lxqtcpuloadconfiguration.cpp" line="69"/>
        <source>Top down</source>
        <translation>Сверху вниз</translation>
    </message>
    <message>
        <location filename="../lxqtcpuloadconfiguration.cpp" line="70"/>
        <source>Left to right</source>
        <translation>Слева направо</translation>
    </message>
    <message>
        <location filename="../lxqtcpuloadconfiguration.cpp" line="71"/>
        <source>Right to left</source>
        <translation>Справа налево</translation>
    </message>
</context>
</TS>

==> lxqt-panel-2.2.0.tar.xz: lxqt-panel-2.2.0/plugin-cpuload/translations/cpuload_ru.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ru">
<context>
    <name>LXQtCpuLoad</name>
    <message>
        <location filename="../lxqtcpuload.cpp" line="126"/>
        <source>CPU load %1%</source>
        <translation>Загрузка процессора %1%</translation>
    </message>
</context>
<context>
    <name>LXQtCpuLoadConfiguration</name>
    <message>
        <location filename="../lxqtcpuloadconfiguration.ui" line="14"/>
        <source>CPU Load Settings</source>
        <translation>Настройки загрузки процессора</translation>
    </message>
    <message>
        <location filename="../lxqtcpuloadconfiguration.ui" line="20"/>
        <source>General</source>
        <translation>Общие</translation>
    </message>
    <message>
        <location filename="../lxqtcpuloadconfiguration.ui" line="35"/>
        <source>Show text</source>
        <translation>Показать текст</translation>
    </message>
    <message>
        <location filename="../lxqtcpuloadconfiguration.ui" line="42"/>
        <source>Update interval:</source>
        <translation>Период обновления:</translation>
    </message>
    <message>
        <location filename="../lxqtcpuloadconfiguration.ui" line="49"/>
        <source>sec</source>
        <translation>сек</translation>
    </message>
    <message>
        <location filename="../lxqtcpuloadconfiguration.ui" line="71"/>
        <source>Bar orientation:</source>
        <translation>Ориентация шкалы:</translation>
    </message>
    <message>
        <location filename="../lxqtcpuloadconfiguration.ui" line="81"/>
        <source>Bar width:</source>
        <translation>Ширина шкалы:</translation>
    </message>
    <message>
        <location filename="../lxqtcpuloadconfiguration.cpp" line="64"/>
        <source>Bottom up</source>
        <translation>Снизу вверх</translation>
    </message>
    <message>
        <location filename="../lxqtcpuloadconfiguration.cpp" line="65"/>
        <source>Top down</source>
        <translation>Сверху вниз</translation>
    </message>
    <message>
        <location filename="../lxqtcpuloadconfiguration.cpp" line="66"/>
        <source>Left to right</source>
        <translation>Слева направо</translation>
    </message>
    <message>
        <location filename="../lxqtcpuloadconfiguration.cpp" line="67"/>
        <source>Right to left</source>
        <translation>Справа налево</translation>
    </message>
</context>
</TS>
